isDebug static method

bool isDebug()

Checks if the application is running in debug mode.

This is determined by an assert statement, which is only executed in debug mode.

Returns true if in debug mode, false otherwise.

Implementation

static bool isDebug() {
  bool inDebugMode = false;
  assert(inDebugMode = true);
  return inDebugMode;
}